@@ -1,4 +1,5 @@
 from json import load
+import os
 
 
 def get_token_list(name):
@@ -11,5 +12,7 @@ def get_token_list(name):
     if name not in TOKEN_LISTS:
         raise Exception('Unknown tokenlists name')
 
-    with open(f'lists/{name}.json') as f:
+    path = f'{os.path.dirname(os.path.realpath(__file__))}/lists/{name}.json'
+
+    with open(path) as f:
         return load(f)
